summaryrefslogtreecommitdiffstats
path: root/libkdegames/kgame/kgameprocess.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:42:31 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:42:31 +0000
commit576eb4299a00bc053db35414406f46372a0f70f2 (patch)
tree4c030922d533821db464af566188e7d40cc8848c /libkdegames/kgame/kgameprocess.h
parent0718336b6017d1a4fc1d626544180a5a2a29ddec (diff)
downloadtdegames-576eb4299a00bc053db35414406f46372a0f70f2.tar.gz
tdegames-576eb4299a00bc053db35414406f46372a0f70f2.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegames@1157643 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libkdegames/kgame/kgameprocess.h')
-rw-r--r--libkdegames/kgame/kgameprocess.h50
1 files changed, 25 insertions, 25 deletions
diff --git a/libkdegames/kgame/kgameprocess.h b/libkdegames/kgame/kgameprocess.h
index a8db4fcd..ac6389be 100644
--- a/libkdegames/kgame/kgameprocess.h
+++ b/libkdegames/kgame/kgameprocess.h
@@ -23,9 +23,9 @@
#ifndef __KGAMEPROCESS_H_
#define __KGAMEPROCESS_H_
-#include <qstring.h>
-#include <qobject.h>
-#include <qfile.h>
+#include <tqstring.h>
+#include <tqobject.h>
+#include <tqfile.h>
#include "kgameproperty.h"
#include <krandomsequence.h>
@@ -60,12 +60,12 @@ class KDE_EXPORT KGameProcess: public QObject
* int main(int argc ,char * argv[])
* {
* KGameProcess proc;
- * connect(&proc,SIGNAL(signalCommand(QDataStream &,int ,int ,int )),
- * this,SLOT(slotCommand(QDataStream & ,int ,int ,int )));
- * connect(&proc,SIGNAL(signalInit(QDataStream &,int)),
- * this,SLOT(slotInit(QDataStream & ,int )));
- * connect(&proc,SIGNAL(signalTurn(QDataStream &,bool )),
- * this,SLOT(slotTurn(QDataStream & ,bool )));
+ * connect(&proc,TQT_SIGNAL(signalCommand(TQDataStream &,int ,int ,int )),
+ * this,TQT_SLOT(slotCommand(TQDataStream & ,int ,int ,int )));
+ * connect(&proc,TQT_SIGNAL(signalInit(TQDataStream &,int)),
+ * this,TQT_SLOT(slotInit(TQDataStream & ,int )));
+ * connect(&proc,TQT_SIGNAL(signalTurn(TQDataStream &,bool )),
+ * this,TQT_SLOT(slotTurn(TQDataStream & ,bool )));
* return proc.exec(argc,argv);
* }
* \endcode
@@ -103,11 +103,11 @@ class KDE_EXPORT KGameProcess: public QObject
* device. Works like the sendSystemMessage but
* for user id's
*
* @param stream the QDataStream containing the message
* @param msgid the message id for the message
* @param receiver unused
*/
- void sendMessage(QDataStream &stream,int msgid,Q_UINT32 receiver=0);
+ void sendMessage(TQDataStream &stream,int msgid,Q_UINT32 receiver=0);
/**
* Sends a system message to the corresonding KGameIO device.
@@ -117,18 +117,18 @@ class KDE_EXPORT KGameProcess: public QObject
* game relevant data from here.
* Exmaple for a query:
* \code
- * QByteArray buffer;
- * QDataStream out(buffer,IO_WriteOnly);
+ * TQByteArray buffer;
+ * TQDataStream out(buffer,IO_WriteOnly);
* int msgid=KGameMessage::IdProcessQuery;
* out << (int)1;
* proc.sendSystemMessage(out,msgid,0);
* \endcode
*
* @param stream the QDataStream containing the message
* @param msgid the message id for the message
* @param receiver unused
*/
- void sendSystemMessage(QDataStream &stream,int msgid,Q_UINT32 receiver=0);
+ void sendSystemMessage(TQDataStream &stream,int msgid,Q_UINT32 receiver=0);
/**
* Returns a pointer to a KRandomSequence. You can generate
@@ -153,7 +153,7 @@ class KDE_EXPORT KGameProcess: public QObject
* A message is received via the interprocess connection. The
* appropriate signals are called.
*/
- void receivedMessage(const QByteArray& receiveBuffer);
+ void receivedMessage(const TQByteArray& receiveBuffer);
signals:
/**
@@ -162,7 +162,7 @@ class KDE_EXPORT KGameProcess: public QObject
* All signals but IdIOAdded and IdTurn end up here!
* Example:
* \code
- * void Computer::slotCommand(int &msgid,QDataStream &in,QDataStream &out)
+ * void Computer::slotCommand(int &msgid,TQDataStream &in,TQDataStream &out)
* {
* Q_INT32 data,move;
* in >> data;
@@ -177,7 +177,7 @@ class KDE_EXPORT KGameProcess: public QObject
* @param receiver the id of the receiver
* @param sender the id of the sender
*/
- void signalCommand(QDataStream &inputStream,int msgid,int receiver,int sender);
+ void signalCommand(TQDataStream &inputStream,int msgid,int receiver,int sender);
/**
* This signal is emmited if the computer player should perform a turn.
@@ -190,12 +190,12 @@ class KDE_EXPORT KGameProcess: public QObject
* stream here.
* Example:
* \code
- * void slotTurn(QDataStream &in,bool turn)
+ * void slotTurn(TQDataStream &in,bool turn)
* {
* int id;
* int recv;
- * QByteArray buffer;
- * QDataStream out(buffer,IO_WriteOnly);
+ * TQByteArray buffer;
+ * TQDataStream out(buffer,IO_WriteOnly);
* if (turn)
* {
* // Create a move - the format is yours to decide
@@ -216,7 +216,7 @@ class KDE_EXPORT KGameProcess: public QObject
* @param turn True or false whether the turn is activated or deactivated
*
*/
- void signalTurn(QDataStream &stream,bool turn);
+ void signalTurn(TQDataStream &stream,bool turn);
/**
* This signal is emmited when the process is initialized, i.e. added
@@ -229,14 +229,14 @@ class KDE_EXPORT KGameProcess: public QObject
* @param stream The datastream which contains user data
* @param userid The userId of the player. (Careful to rely on it yet)
*/
- void signalInit(QDataStream &stream,int userid);
+ void signalInit(TQDataStream &stream,int userid);
protected:
bool mTerminate;
KMessageFilePipe *mMessageIO;
private:
- QFile rFile;
- QFile wFile;
+ TQFile rFile;
+ TQFile wFile;
KRandomSequence* mRandom;
};
#endif
@@ -103,11 +103,11 @@ class KDE_EXPORT KGameProcess: public QObject
* for user id's
*
- * @param stream the QDataStream containing the message
+ * @param stream the TQDataStream containing the message
* @param msgid the message id for the message
* @param receiver unused
@@ -117,18 +117,18 @@ class KDE_EXPORT KGameProcess: public QObject
* \endcode
*
- * @param stream the QDataStream containing the message
+ * @param stream the TQDataStream containing the message
* @param msgid the message id for the message
* @param receiver unused